@@ -114,7 +114,8 @@ class ValueObject(IntrospectableObject):
 
 
 class Entity(IntrospectableObject):
-    """ Pydantic based Entity object
+    """
+    Pydantic based Entity object
 
     Entity object based on pydantic and the "new way" of creating entities in
     our minty platform. It has the same functionality as the EntityBase object,
@@ -156,11 +157,12 @@ class Entity(IntrospectableObject):
     )
 
     entity_changelog: list = []
+    entity_data: dict = {}
 
     _event_service = None
 
     def __init__(self, **kwargs):
-        """ Initialized an Entity object
+        """Initialized an Entity object
 
         Initialized an entity object and calls super().__init__ on the pydantic
         based IntrospectableObject model. Allows the setting of _event_service
@@ -174,7 +176,7 @@ class Entity(IntrospectableObject):
             )
 
     def entity_dict(self):
-        """ Generates a python dict containing the values of this entity
+        """Generates a python dict containing the values of this entity
 
         Just as the pydantic.dict() method, it returns a dict containing the
         key/values of the attributes of this object.
@@ -213,9 +215,14 @@ class Entity(IntrospectableObject):
 
         return rv
 
+    def capture_field_values(self, fields: List):
+        for field in fields:
+            value = self.__getattribute__(field)
+            self.entity_data[field] = _reflect(value)
+
     @staticmethod
-    def event(name: str):
-        """ New event decorator to capture entity changes and publish events to
+    def event(name: str, extra_fields: List = None):
+        """New event decorator to capture entity changes and publish events to
         the event_service.
 
         :param name: Name of event to publish
@@ -255,13 +262,16 @@ class Entity(IntrospectableObject):
 
                 wrapped_entity = rv
 
+            if extra_fields is not None:
+                wrapped_entity.capture_field_values(fields=extra_fields)
+
             try:
                 wrapped_entity._event_service.log_event(
                     entity_type=wrapped_entity.__class__.__name__,
                     entity_id=str(wrapped_entity.entity_id),
                     event_name=name,
                     changes=changelog,
-                    entity_data={},
+                    entity_data=wrapped_entity.entity_data,
                 )
             except AttributeError as e:
                 raise exceptions.ConfigurationConflict(
